@@ -29,7 +29,7 @@ def read_scalar_data(filepath):
         flat numpy array of scalar data
     """
     try:
-        scalar_data = nib.load(filepath).get_data()
+        scalar_data = np.asanyarray(nib.load(filepath).dataobj)
         scalar_data = np.ravel(scalar_data, order="F")
         return scalar_data
 
@@ -229,7 +229,7 @@ def project_volume_data(filepath, hemi, reg_file=None, subject_id=None,
     # Execute the command
     out_file = mktemp(prefix="pysurfer-v2s", suffix='.mgz')
     cmd_list.extend(["--o", out_file])
-    logger.info(" ".join(cmd_list))
+    logger.debug(" ".join(cmd_list))
     p = Popen(cmd_list, stdout=PIPE, stderr=PIPE, env=env)
     stdout, stderr = p.communicate()
     out = p.returncode
