@@ -579,10 +579,36 @@ def smoothing_matrix(vertices, adj_mat, smoothing_steps=20, verbose=None):
     smooth_mat : sparse matrix
         smoothing matrix with size N x len(vertices)
     """
+    if smoothing_steps == 'nearest':
+        mat = _nearest(vertices, adj_mat)
+    else:
+        mat = _smooth(vertices, adj_mat, smoothing_steps)
+    return mat
+
+
+def _nearest(vertices, adj_mat):
+    import scipy
+    from scipy.sparse.csgraph import dijkstra
+    if LooseVersion(scipy.__version__) < LooseVersion('1.3'):
+        raise RuntimeError('smoothing_steps="nearest" requires SciPy >= 1.3')
+    # Vertices can be out of order, so sort them to start ...
+    order = np.argsort(vertices)
+    vertices = vertices[order]
+    _, _, sources = dijkstra(adj_mat, False, indices=vertices, min_only=True,
+                             return_predecessors=True)
+    col = np.searchsorted(vertices, sources)
+    # ... then get things back to the correct configuration.
+    col = order[col]
+    row = np.arange(len(col))
+    data = np.ones(len(col))
+    mat = sparse.coo_matrix((data, (row, col)))
+    assert mat.shape == (adj_mat.shape[0], len(vertices)), mat.shape
+    return mat
+
+
+def _smooth(vertices, adj_mat, smoothing_steps):
     from scipy import sparse
-
-    logger.info("Updating smoothing matrix, be patient..")
-
+    logger.debug("Updating smoothing matrix, be patient..")
     e = adj_mat.copy()
     e.data[e.data == 2] = 1
     n_vertices = e.shape[0]
@@ -600,7 +626,7 @@ def smoothing_matrix(vertices, adj_mat, smoothing_steps=20, verbose=None):
 
         smooth_mat = scale_mat * e_use[idx_use, :] * smooth_mat
 
-        logger.info("Smoothing matrix creation, step %d" % (k + 1))
+        logger.debug("Smoothing matrix creation, step %d" % (k + 1))
         if smoothing_steps is None and len(idx_use) >= n_vertices:
             break
 
@@ -664,7 +690,7 @@ def coord_to_label(subject_id, coord, label, hemi='lh', n_steps=30,
     idx = np.where(data.ravel() > 0)[0]
     # Write label
     label_fname = label + '-' + hemi + '.label'
-    logger.info("Saving label : %s" % label_fname)
+    logger.debug("Saving label : %s" % label_fname)
     f = open(label_fname, 'w')
     f.write('#label at %s from subject %s\n' % (coord, subject_id))
     f.write('%d\n' % len(idx))
@@ -745,3 +771,10 @@ def requires_fs():
     has = ('FREESURFER_HOME' in os.environ)
     return pytest.mark.skipif(
         not has, reason='Requires FreeSurfer command line tools')
+
+
+def _get_extra():
+    # Get extra label for newer freesurfer
+    subj_dir = _get_subjects_dir()
+    fname = op.join(subj_dir, 'fsaverage', 'label', 'lh.BA1.label')
+    return '_exvivo' if not op.isfile(fname) else '', subj_dir
